# Statisticas
Description. 
The package Statisticas is used to:
	- Calculate the central trend measure
	- Calculate the dispersion measure

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install statisitcs

```bash
pip install statisticas
```

## Author
LucasMGuima

## License
[MIT](https://choosealicense.com/licenses/mit/)